import {requestInstance} from "@/service";

//用户管理 首页查询
export function proXyxxSelectYhgl(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxSelectYhgl',
        data:{
            ...params
        }
    })
}

//用户管理 详情页单位查询
export function proSelectUnitnew(params){
    return requestInstance({
        url:'/XyxxApi/proSelectUnitnew',
        data:{
            ...params
        }
    })
}




//用户管理  详情页下属部门查询
export function proSelectXyxxDepartment(params){
    return requestInstance({
        url:'/XyxxApi/proSelectXyxxDepartment',
        data:{
            ...params
        }
    })
}


//用户管理 详情页应用事项列表查询
export function proXyxxSystemUnitYysx(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxSystemUnitYysx',
        data:{
            ...params
        }
    })
}

//用户管理 详情页当前应用事项查询
export function proXyxxSelectUnitYysx(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxSelectUnitYysx',
        data:{
            ...params
        }
    })
}

//用户管理  验证用户是否存在
export function proXyxxSelectUsername(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxSelectUsername',
        data:{
            ...params
        }
    })
}


//用户管理  详情页新增用户
export function proXyxxInsertYhgl(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxInsertYhgl',
        data:{
            ...params
        }
    })
}

//用户管理  详情页修改用户
export function proXyxxUpdateYhgl(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxUpdateYhgl',
        data:{
            ...params
        }
    })
}


//用户管理  首页删除
export function proXyxxDeleteSystemYhgl(params){
    return requestInstance({
        url:'/XyxxApi/proXyxxDeleteSystemYhgl',
        data:{
            ...params
        }
    })
}
